import request from '@/utils/request'

// 查询用户车辆列表
export function listCar(data) {
  return request({
    url: '/tCar/list',
    method: 'post',
    data: data
  })
}

// 查询用户车辆详细
export function getCar(id) {
  return request({
    url: '/tCar/' + id,
    method: 'get'
  })
}

// 新增用户车辆
export function addCar(data) {
  return request({
    url: '/tCar',
    method: 'post',
    data: data
  })
}

// 修改用户车辆
export function updateCar(data) {
  return request({
    url: '/tCar',
    method: 'put',
    data: data
  })
}

// 删除用户车辆
export function delCar(id) {
  return request({
    url: '/tCar/' + id,
    method: 'delete'
  })
}

// 导入用户车辆
export function importData(data) {
  return request({
    url: '/tCar/import',
    method: 'post',
    data: data
  })
}

// 导出用户车辆
export function exportCar(data) {
  return request({
    url: '/tCar/export',
    method: 'post',
    data: data
  })
}
